@@ -6,26 +6,24 @@ use base 'Fennec::Collector::TB';
 
 use File::Temp;
 
-use Fennec::Util qw/ accessors /;
+use Fennec::Util qw/ accessors verbose_message /;
 
 accessors qw/tempdir handles tempobj _pid/;
 
-sub validate_env { 1 }
-
 sub new {
     my $class = shift;
 
+    my $self = $class->SUPER::new(@_);
+
     my $temp = File::Temp::tempdir( CLEANUP => 0 );
-    print STDERR "# Using temp dir: '$temp' for process results\n"
-        if $ENV{HARNESS_IS_VERBOSE};
+    verbose_message("# Using temp dir: '$temp' for process results\n");
 
-    return bless {
-        _pid    => $$,
-        handles => {},
+    $self->_pid($$);
+    $self->handles( {} );
+    $self->tempobj($temp);
+    $self->tempdir("$temp");
 
-        tempobj => $temp,
-        tempdir => "$temp",
-    }, $class;
+    return $self;
 }
 
 sub report {
@@ -138,6 +136,11 @@ sub DESTROY {
 
 __END__
 
+=head1 NAME
+
+Fennec::Collector::TB::TempFiles - Test::Builder collector that uses temporary
+files to convey results.
+
 =head1 AUTHORS
 
 Chad Granum L<exodist7@gmail.com>
